Package: ivygapSE
Title: A SummarizedExperiment for Ivy-GAP data
Description: Define a SummarizedExperiment and exploratory app for Ivy-GAP glioblastoma image, expression, and clinical data.
Version: 1.35.2
Author: Vince Carey
Suggests: knitr, png, limma, grid, DT, randomForest, digest, testthat,
        rmarkdown, BiocStyle, magick, statmod, codetools
Depends: R (>= 3.5.0), SummarizedExperiment, BiocFileCache
Imports: shiny, survival, hwriter, plotly, ggplot2, S4Vectors,
        graphics, stats, utils
Maintainer: VJ Carey <stvjc@channing.harvard.edu>
License: Artistic-2.0
LazyLoad: yes
biocViews: Transcription, Software, Visualization, Survival,
        GeneExpression, Sequencing
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/ivygapSE
git_branch: devel
git_last_commit: e705549
git_last_commit_date: 2026-06-22
Repository: Bioconductor 3.24
Date/Publication: 2026-06-22
NeedsCompilation: no
Packaged: 2026-06-22 22:29:51 UTC; biocbuild

# Generated by roxygen2: do not edit by hand

export(designOverview)
export(exprByType)
export(getRefLimma)
export(ivyGlimpse)
export(makeGeneSets)
export(nomenclat)
export(subBlockDetails)
export(tumorDetails)
export(vocab)
import(SummarizedExperiment)
import(ggplot2, except=last_plot)
import(hwriter)
import(plotly)
import(shiny)
import(survival)
importFrom(S4Vectors,metadata)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,boxplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(stats,median)
importFrom(utils,browseURL)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,packageVersion)

# ivygapSE

This package provides a SummarizedExperiment for Ivy-GAP metadata.  See the [ivyGlimpse app](http://vjcitn.shinyapps.io/ivyglimpse) and an [explanatory video](https://www.youtube.com/watch?v=4qJaodLEI5o).

The metadata and expression data are
as distributed by [Allen Institute for Brain Science](http://glioblastoma.alleninstitute.org/static/download.html) as of 31 May 2017.

A brief vignette is available, and the ivyGlimpse() function will initiate a shiny app
for exploring relationships between sub-block level image features quantified in 'subBlockDetails',
survival time, and expression patterns.  Essentially, one can use a scatterplot of
a pair of image features to stratify the data.

ivyGlimpse will be accompanied by ivyTest, a tool for formally testing hypotheses
relating image characteristics to expression patterns, and ivyBridge, which will
emphasize interactive amalgamation of data and annotation related to glioblastoma.

#' demonstration of gene set construction for ivyGlimpse app
#' @note Should be replaced by selections from a general catalog.
#' @return list of gene sets with attributes facilitating
#' dropdown construction -- attr(,"fullTitle") is a list of strings
#' associated with gene set elements (named list with vectors 
#' of gene symbols constituting sets of interest) \cr
#' List of 4 \cr
#'  $ General: Ras-Raf-MEK-Erk/JNK signaling (26 genes) \cr                                      : chr [1:26] "KRAS" "HRAS" "BRAF" "RAF1" ... \cr
#'  $ Glioblastoma: RTK/Ras/PI3K/AKT Signaling (17 genes) \cr                                    : chr [1:17] "EGFR" "ERBB2" "PDGFRA" "MET" ... \cr
#'  $ General: PI3K-AKT-mTOR signaling (17 genes)            \cr                                : chr [1:17] "PIK3CA" "PIK3R1" "PIK3R2" "PTEN" ... \cr
#'  $ Ovarian Cancer: Putative tumor-suppressor genes in epithelial ovarian cancer (16 genes) \cr : chr [1:16] "DIRAS3" "RASSF1" "DLEC1" "SPARC" ... \cr
#'  - attr(*, "fullTitle")=List of 4 \cr
#'   ..$ glioRTK  : chr "Glioblastoma: RTK/Ras/PI3K/AKT Signaling (17 genes)" \cr
#'   ..$ pi3k     : chr "General: PI3K-AKT-mTOR signaling (17 genes)" \cr
#'   ..$ ovtumsupp: chr "Ovarian Cancer: Putative tumor-suppressor genes in epithelial ovarian cancer (16 genes)" \cr
#'   ..$ rasraf   : chr "General: Ras-Raf-MEK-Erk/JNK signaling (26 genes)" \cr
#' @examples
#' str(makeGeneSets())
#' @export
makeGeneSets = function() {
   glioRTK = c(
   "EGFR","ERBB2","PDGFRA","MET","KRAS","NRAS","HRAS","NF1","SPRY2","FOXO1","FOXO3","AKT1","AKT2","AKT3","PIK3R1","PIK3CA","PTEN"
   )
   
   pi3k = c(
   "PIK3CA","PIK3R1","PIK3R2","PTEN","PDPK1","AKT1","AKT2","FOXO1","FOXO3","MTOR","RICTOR","TSC1","TSC2","RHEB","AKT1S1","RPTOR","MLST8"
   )
   
   ovtumsupp=c("DIRAS3","RASSF1","DLEC1","SPARC","DAB2","PLAGL1","RPS6KA2","PTEN","OPCML","BRCA2","ARL11","WWOX","TP53","DPH1","BRCA1","PEG3")
   
   rasraf = c("KRAS","HRAS","BRAF","RAF1","MAP3K1","MAP3K2","MAP3K3","MAP3K4","MAP3K5","MAP2K1","MAP2K2","MAP2K3","MAP2K4","MAP2K5",
     "MAPK1","MAPK3","MAPK4","MAPK6","MAPK7","MAPK8","MAPK9","MAPK12","MAPK14","DAB2","RASSF1","RAB25")
   
   someSets = list(rasraf=rasraf, glioRTK=glioRTK,
      pi3k=pi3k,
      ovtumsupp = ovtumsupp)
   
   attr(someSets, "fullTitle") = list(
      glioRTK="Glioblastoma: RTK/Ras/PI3K/AKT Signaling (17 genes)",
      pi3k="General: PI3K-AKT-mTOR signaling (17 genes)",
      ovtumsupp = "Ovarian Cancer: Putative tumor-suppressor genes in epithelial ovarian cancer (16 genes)",
      rasraf = "General: Ras-Raf-MEK-Erk/JNK signaling (26 genes)")
   
   names(someSets) = unlist(attr(someSets, "fullTitle")[names(someSets)])
   
   someSets
}

utils::globalVariables("ivySE")

#' ivySE: SummarizedExperiment for IvyGAP expression data and metadata
#' @format SummarizedExperiment instance
#' @note
#' Expression data retrieved from \url{http://glioblastoma.alleninstitute.org/api/v2/well_known_file_download/305873915}
#' @details
#' %vjcair> unzip -l gene*zip \cr
#' Archive:  gene_expression_matrix_2014-11-25.zip \cr
#'   Length      Date    Time    Name \cr
#' ---------  ---------- -----   ---- \cr
#'     50585  03-31-2015 13:27   columns-samples.csv \cr
#'  86153820  10-31-2014 14:04   fpkm_table.csv \cr
#'      2015  11-24-2014 18:06   README.txt \cr
#'   1689619  10-31-2014 13:55   rows-genes.csv \cr
#' ---------                     ------- \cr
#'  87896039                     4 files \cr
#' @source processed from \url{glioblastoma.alleninstitute.org}; see Note.
#' @examples
#' \dontrun{   # how it was made
#' ivyFpkm = read.csv("fpkm_table.csv", stringsAsFactors=FALSE, 
#'       check.names=FALSE)
#' g = read.csv("rows-genes.csv", stringsAsFactors=FALSE)
#' library(SummarizedExperiment)
#' imat = data.matrix(ivyFpkm[,-1])
#' ivySE = SummarizedExperiment(SimpleList(fpkm=imat))
#' rowData(ivySE) = g
#' rownames(ivySE) = g$gene_symbol
#' col = read.csv("columns-samples.csv", stringsAsFactors=FALSE)
#' rownames(col) = col$rna_well_id
#' stopifnot(all.equal(as.character(col$rna_well_id), 
#'      as.character(colnames(imat))))
#' colData(ivySE) = DataFrame(col)
#' colnames(ivySE) = colnames(imat)
#' metadata(ivySE) = list(README=readLines("README.txt"))
#' metadata(ivySE)$URL = "http://glioblastoma.alleninstitute.org/static/download.html"
#' # metadata(ivySE)$builder = readLines("build.R")
#' de = read.csv("tumor_details.csv", stringsAsFactors=FALSE)
#' metadata(ivySE)$tumorDetails = de
#' subbl = read.csv("sub_block_details.csv", stringsAsFactors=FALSE)
#' metadata(ivySE)$subBlockDetails = subbl
#' bamtab = read.csv("bam.csv", stringsAsFactors=FALSE)
#' rownames(bamtab) = as.character(bamtab$rna_well)
#' bamtab[colnames(ivySE),] -> bamtreo
#' all.equal(rownames(bamtreo), colnames(ivySE))
#' colData(ivySE) = cbind(colData(ivySE), bamtreo)
#' }
#' data(ivySE)
#' names(metadata(ivySE))
"ivySE"

#' helper functions for data access
#' @rdname helper
#' @param se SummarizedExperiment instance, intended to work for ivySE in this package
#' @aliases tumorDetails
#' @return data.frames for tumorDetails, subBlockDetails and vocab
#' @examples
#' data(ivySE)
#' dim(tumorDetails(ivySE))
#' @export
tumorDetails = function(se) metadata(se)$tumorDetails
#' @rdname helper
#' @aliases subBlockDetails
#' @export
subBlockDetails = function(se) metadata(se)$subBlockDetails
#' @rdname helper
#' @aliases vocab
#' @export
vocab = function() {
data.frame(
 abbr = c("PAN", "PNN", "NE", "BV", "HBV", "MVP", "EN",
   "CT", "CTpnz", "HE", "FOLD", "SPA"),
 def = c("pseudopalisading cells around necrosis",
"pseudopalisading cells no necrosis",
"necrosis", "blood vessels", "hyperplastic blood vessels",
"microvascular proliferation", "early necrosis",
"cellular tumor", "cellular tumor perinecrotic zone",
"hemorrhage", "tissue fold", "space"))
}

#' provide access to a limma analysis of RNA-seq profiles for reference histology samples
#' @importFrom utils download.file
#' @note Uses \code{\link[utils]{download.file}} to acquire RDS of the output
#' of \code{\link[limma]{eBayes}} from a public S3 bucket.  The limma model
#' was fit using \code{\link[limma]{duplicateCorrelation}} to address multiplicity
#' of contributions per donor.  Comparisons are to samples labeled \code{CT-reference} (cellular tumor, reference contributions),
#' with coefficients 2-5 corresponding to CT-mvp (microvascular proliferation),
#' CT-pan (pseudopalisading cells around necrosis), IT (infiltrating tumor),
#' and LE (leading edge), respectively.
#' @return an instance of \code{\link[limma]{MArrayLM-class}} representing regularized gene-wise ANOVAs
#' @examples
#' requireNamespace("limma")
#' ebout = getRefLimma() # is result of eBayes
#' colnames(ebout$coef)
#' limma::topTable(ebout,2)
#' @export
getRefLimma = function() {
 if (!requireNamespace("limma")) stop("install limma to use this function")
 tf = tempfile()
 download.file("https://s3.amazonaws.com/bcfound-itcr/histoLimma.rds", tf, mode="wb")
 readRDS(tf)
}

library(ivygapSE)

context("testTargets")
test_that("test suite knows how many functions are exported", {
  exported = ls("package:ivygapSE")
  expect_true(length(exported)==9)
})

context("constantVectors")
test_that("vector lengths as anticipated", {
  expect_true(all(dim(vocab())==c(12,2)))
  gs = makeGeneSets()
  expect_true(all(sapply(gs, length)==c(26,17,17,16)))
})

context("exprPlot")
test_that("exprByType for MYC as expected", {
  et = exprByType("MYC")
  expect_true(all(names(et)==c("exprs", "types")))
  expect_true(length(et$exprs)==6)
})

context("limmaRetrieval")
test_that("getRefLimma returns expected structure", {
  requireNamespace("digest")
  grl = getRefLimma()
  expect_true(digest::digest(grl)=="89c0a44f3d1aaf374518dd3f56a8ca96")
})

context("metadataStructure")
test_that("check metadata components of ivySE", {
  data(ivySE)
  md = metadata(ivySE)
  expect_true(all(names(md)==c("README", "URL", "builder", 
         "tumorDetails", "subBlockDetails")))
  expect_true(length(md$builder)==12)
  expect_true(all(dim(md$tumorDetails)==c(42,10)))
  expect_true(all(dim(md$subBlockDetails)==c(946,26)))
})

#' simple plot of expression values by structure/expression-based selection in IvyGAP
#' @importFrom graphics axis plot
#' @param sym a gene symbol found among `rownames(ivySE)`
#' @param \dots passed to plot, exclusive of ylab, xlab, axes
#' @return invisibly returns a list with two elements: exprs, the vector of expression values, and types, the vector of structure types
#' @examples
#' exprByType("MYC")
#' @export
exprByType = function (sym, ...) 
{
    if (!exists("ivySE")) data(ivySE)
    stopifnot(sym %in% rownames(ivySE))
    opar = par(no.readonly=TRUE)
    par(mar=c(11,4,2,2))
    on.exit(par(opar))
    inds = grep(sym, ivySE$structure_acronym)
    if (length(inds)==0) stop(sprintf("%s not found among genes used for RNA-seq sample selection", sym))
    n = length(inds)
    plot(1:n,  sav <- assay(ivySE)[sym, inds], ylab = sym, xlab = "sample type", 
        axes = FALSE, ...)
    axis(2)
    axis(1, at = 1:n, labels = (types <- ivySE$structure_acronym[inds]), 
        las = 2)
    invisible(list(exprs=sav, types=types))
}

## ----loadup, echo=FALSE,message=FALSE-----------------------------------------
suppressPackageStartupMessages({
library(SummarizedExperiment)
library(ivygapSE)
library(DT)
library(grid)
library(png)
library(ggplot2)
library(limma)
library(randomForest)
})

## ----chk,message=FALSE--------------------------------------------------------
library(ivygapSE)
data(ivySE)
ivySE

## ----lkd----------------------------------------------------------------------
dim(ivySE)

## ----lkse---------------------------------------------------------------------
length(unique(metadata(ivySE)$tumorDetails$donor_id))

## ----lkcon--------------------------------------------------------------------
sum(metadata(ivySE)$tumorDetails$tumor_name %in% ivySE$tumor_name)

## ----getsbd,echo=FALSE--------------------------------------------------------
subd = metadata(ivySE)$subBlockDetails
dsub = dim(subd)

## ----lkonto,image=TRUE,echo=FALSE---------------------------------------------
nomenclat()

## ----lkk,echo=FALSE,fig=TRUE--------------------------------------------------
designOverview()

## ----lkdttum,echo=FALSE-------------------------------------------------------
datatable(tumorDetails(ivySE), options=list(lengthMenu=c(3,5,10,50,100)))

## ----lkdts,echo=FALSE---------------------------------------------------------
datatable(subBlockDetails(ivySE), options=list(lengthMenu=c(3,5,10,50,    100)))

## ----lkcdd,echo=FALSE---------------------------------------------------------
datatable(as.data.frame(colData(ivySE)), options=list(lengthMenu=c(3,5,10,50,100)))

## ----lksbbbb------------------------------------------------------------------
sb = subBlockDetails(ivySE)
table(sb$study_name)

## ----lksa,fig=TRUE------------------------------------------------------------
struc = as.character(colData(ivySE)$structure_acronym)
spls = strsplit(struc, "-")
basis = vapply(spls, function(x) x[1], character(1))
spec = vapply(spls, function(x) x[2], character(1))
table(basis, exclude=NULL)
barplot(table(basis))

## ----lktab--------------------------------------------------------------------
lapply(split(spec,basis), function(x)sort(table(x),decreasing=TRUE))

## ----lklim, cache=TRUE--------------------------------------------------------
library(limma)
ebout = getRefLimma()

## ----lknnn--------------------------------------------------------------------
odig = options()$digits
options(digits=3)
limma::topTable(ebout, 2)
options(digits=odig) # revert

## ----bindmol------------------------------------------------------------------
moltype = tumorDetails(ivySE)$molecular_subtype
names(moltype) = tumorDetails(ivySE)$tumor_name
moltype[nchar(moltype)==0] = "missing"
ivySE$moltype = factor(moltype[ivySE$tumor_name])

## ----setdup, cache=TRUE-------------------------------------------------------
library(limma)
refex = ivySE[, grep("reference", ivySE$structure_acronym)]
refmat = assay(refex)
tydes = model.matrix(~moltype, data=as.data.frame(colData(refex)))
ok = which(apply(tydes,2,sum)>0)  # some subtypes don't have ref histo samples
tydes = tydes[,ok]
block = factor(refex$tumor_id)
dd = duplicateCorrelation(refmat, tydes, block=block)
f2 = lmFit(refmat, tydes, correlation=dd$consensus)
ef2 = eBayes(f2)
colnames(tydes)
topTable(ef2,2)

## ----lkrf,fig=TRUE------------------------------------------------------------
refex = ivySE[, grep("reference", ivySE$structure_acronym)]
refex$struc = factor(refex$structure_acronym)
iqrs = rowIQRs(assay(refex))
inds = which(iqrs>quantile(iqrs,.5))
set.seed(1234)
rf1 = randomForest(x=t(assay(refex[inds,])), 
        y=refex$struc, mtry=30, importance=TRUE) 
rf1
varImpPlot(rf1)

renderPNG = function(fi) {
  if (!requireNamespace("png")) stop("install png to run this function")
  if (!requireNamespace("grid")) stop("install grid to run this function")
  p = png::readPNG(system.file(paste0("pngs/", fi), package="ivygapSE"))
  grid::grid.raster(p)
}

#' render design overview
#' @rdname imgSupport
#' @aliases designOverview
#' @return a rastergrob grob
#' @examples
#' designOverview()
#' @export
designOverview = function()
  renderPNG("whiteSixStud.png")
#' render anatomic nomenclature
#' @rdname imgSupport
#' @aliases nomenclat
#' @export
nomenclat = function()
  renderPNG("anatomicNomenclature.png")

#' simple app to explore image property quantifications in relation to survival and expression
#' @import shiny
#' @importFrom utils packageVersion
#' @importFrom S4Vectors metadata
#' @import hwriter
#' @import SummarizedExperiment
#' @import survival
#' @import plotly
#' @importFrom graphics barplot boxplot legend par
#' @importFrom stats median
#' @importFrom utils browseURL data
#' @rawNamespace import(ggplot2, except=last_plot)
#' @return Side effect of starting the app only.
#' @examples
#' if (interactive()) print(ivyGlimpse())
#' @export
ivyGlimpse = function() {

## START UI
# define gene sets from cbioPortal

    someSets = makeGeneSets()
    
    #ivySE = NULL
    #data(ivySE)
    load(system.file("data/ivySE.rda", package="ivygapSE"))
    
    sb = metadata(ivySE)$subBlockDetails
    sb = sb[!is.na(sb$survival_days),]
    
    feats = colnames(sb)
    
    ui = fluidPage(
     sidebarLayout(
      sidebarPanel(
       fluidRow(
          helpText("IvyGAP explorer: expression, clinical, and image-based data for glioblastoma patients; see background panel for more details")
       ),
       fluidRow(
          helpText("subBlockDetail features for selectables scatterplot")
       ),
       fluidRow(
        selectInput("x", "x", choices=feats, selected="normalized_area_it")
       ),
       fluidRow(
        selectInput("y", "y", choices=feats, selected="normalized_area_ct")
       ), 
       fluidRow(
        selectInput("gs", "cbioP sets", choices=names(someSets), selected=names(someSets)[1])
       ),
       fluidRow(
        helpText("Supported by NCI ITCR U01 CA214846 and U24 CA180996")
       ),
       width=3
      ),
      mainPanel(
       tabsetPanel(
        tabPanel("basic",
         fluidRow(
          column( 
           fluidRow( helpText("hover over for tumor donor ID; partition data by dragging over points to select; click on a specific point to visit IvyGAP clinical specimen page for that sample") ),
           fluidRow( plotlyOutput("xyplot") ), width=5 ),
          column( 
           fluidRow( helpText("Kaplan-Meier, grp=1 for selected donors") ),
           fluidRow( plotOutput("plot2") ), width=5)
          ),
         fluidRow(
          column( plotOutput("boxes1"), width=5 ),
          column( plotOutput("boxes2"), width=5 )
          )
         ),
        tabPanel("vocabulary", tableOutput("vocab")),
        tabPanel("background", 
         fluidRow(
           textOutput("versinfo"),
           textOutput("commentary"),
           plotOutput("upset")
           ),
         fluidRow(
           helpText("Read the ", a(href='http://help.brain-map.org/display/glioblastoma/Documentation?preview=/8028197/8454231/IvyOverview.pdf', 'Allen Institute Technical White Paper'))
          ),
         fluidRow(helpText("The README from the ", a(href='http://glioblastoma.alleninstitute.org/api/v2/well_known_file_download/305873915',"zip archive of expression data"))),
         fluidRow(verbatimTextOutput("bkgrd"))
         )
        )
       )
      )
     )
    
    ## END UI
    ## START SERVER
    
    featanno = c("normalized_area_le"   =   
    "Leading Edge (LE)",
    "normalized_area_lehbv" =
    "Hyperplastic blood vessels in leading edge (LEhbv)",
    "normalized_area_it"   =   
    "Infiltrating Tumor (IT)",
    "normalized_area_ithbv" =
    "Hyperplastic blood vessels in infiltrating tumor (IThbv)",
    "normalized_area_ct"   =   
    "Cellular Tumor (CT)",
    "normalized_area_ctpnz" =
    "Perinecrotic zone (CTpnz)",
    "normalized_area_cthbv" =
    "Hyperplastic blood vessels in cellular tumor (CThbv)",
    "normalized_area_ctpnn" =
    "Pseudopalisading cells but no visible necrosis (CTpnn)",
    "normalized_area_ctpan" =
    "Pseudopalisading cells around necrosis (CTpan)",
    "normalized_area_ctmvp" =
    "Microvascular proliferation (CTmvp)",
    "normalized_area_ctne" =
    "Necrosis (CTne)")
    
    molmap = structure(c("NA", "C", "CM", "CN", "M", "MN", "N", "NP", "P"), .Names = c("", 
       "Classical", "Classical, Mesenchymal", "Classical, Neural", "Mesenchymal", 
       "Mesenchymal, Neural", "Neural", "Neural, Proneural", "Proneural"
       ))
    
    server = function(input, output, session) {
     sb = metadata(ivySE)$subBlockDetails
     sb = sb[!is.na(sb$survival_days),]
     output$xyplot = renderPlotly({
       df = sb[, c(input$x, input$y, "donor_id", "molecular_subtype",
                    "specimen_page_link")]
       df$donor_id = paste0("donor: ", df$donor_id)
       df$molm = molmap[df$molecular_subtype]
       gp = plot_ly(df,
              x = df[[input$x]],
              y = df[[input$y]],
              text = ~donor_id,
              type = "scatter",
              mode = "markers",
              source = "subset") %>%
            layout(dragmode = "select",
                   xaxis = list(title = input$x),
                   yaxis = list(title = input$y)) %>%
            event_register("plotly_selected")
       event.data <- event_data("plotly_click", source = "subset")
       if (!is.null(event.data)) browseURL(df[event.data$pointNumber+1,
           "specimen_page_link"])
       gp
       })
     
    procSel = reactive({
        event.data <- event_data("plotly_selected", source = "subset")
        if(is.null(event.data) == TRUE) return(NULL)
        dr = duplicated(sb$donor_id)
        udf <<- sb[-which(dr),]  # survfit does not find without <<-
        udf$grp <<- 0
        sdf = sb[event.data$pointNumber+1,]
        indo = sdf$donor_id
        udf[which(udf$donor_id %in% indo),]$grp <<- 1
        survfit(Surv(survival_days, rep(1,nrow(udf)))~grp, data=udf)
        })
     
     output$plot2 = renderPlot({
        validate(need(!is.null(procSel()), "waiting for (dragged) selection"))
        mm = procSel()
        plot(mm, col=c("black","red"), lty=1:2,
             xlab="days", ylab="survival probability",
             main="Kaplan-Meier, grp=1 for selected donors")
        legend("topright", legend=c("grp=0","grp=1"),
               col=c("black","red"), lty=1:2)
       })
    
     output$boxes1 = renderPlot({
        # Get subset based on selection
        event.data <- event_data("plotly_selected", source = "subset")
        # If NULL dont do anything
        if(is.null(event.data) == TRUE) return(NULL)
        dr = duplicated(sb$donor_id)
        udf <<- sb[-which(dr),]
        udf$grp = 0
        sdf = sb[event.data$pointNumber+1,]
        intu = sdf$tumor_name
        seSEL = ivySE[someSets[[input$gs]], which(ivySE$tumor_name %in% intu)]
        logp = function(x) log(x+1)
        par(mar=c(5,4,2,2))
        meds = apply(assay(seSEL),1,median,na.rm=TRUE)
        omeds = order(meds)
        boxplot( data.frame(logp(t(assay(seSEL)[omeds,]))), main="in image subset", las=2, ylab="log fpkm",
          ylim=c(0,7))
       })
    
     output$boxes2 = renderPlot({
        # Get subset based on selection
        event.data <- event_data("plotly_selected", source = "subset")
        # If NULL dont do anything
        if(is.null(event.data) == TRUE) return(NULL)
        dr = duplicated(sb$donor_id)
        udf <<- sb[-which(dr),]
        udf$grp = 0
        sdf = sb[event.data$pointNumber+1,]
        intu = sdf$tumor_name
        seSEL = ivySE[someSets[[input$gs]], which(ivySE$tumor_name %in% intu)] # for ordering
        meds = apply(assay(seSEL),1,median,na.rm=TRUE)
        omeds = order(meds)
        seUNSEL = ivySE[someSets[[input$gs]], -which(ivySE$tumor_name %in% intu)]
        logp = function(x) log(x+1)
        par(mar=c(5,4,2,2))
        boxplot( data.frame(logp(t(assay(seUNSEL)[omeds,]))), main="not in image subset", las=2, ylab="log fpkm",
            ylim=c(0,7))
       })
      output$vocab = renderTable({
        plop = function(x) gsub("^", " ", x)
        data.frame(short=c("_Molec. subtype_", names(molmap), "_Feature_", names(featanno)), 
                 long=c(" ", as.character(molmap), " ", as.character(featanno)))
        })
      output$bkgrd = renderText( paste(metadata(ivySE)$README, collapse="\n") )
      output$versinfo = renderText( paste0("ivygapSE version ", 
                              as.character(packageVersion("ivygapSE"))) )
      output$commentary = renderText( paste(
           "This app introduces users to quantitative elements of the Ivy Glioblastoma Atlas project.",
           "Tumors are divided into blocks and subblocks.  Subblocks are associated with",
           "image-derived measures such as proportions of cells deemed infiltrating or cellular,",
           "and with measures of gene expression derived from RNA-seq on 270=122+148 samples",
           "microdissected after selection anatomic and molecular criteria.",
           "'Donor' refers to the individual patient, and survival times are recorded for most patients.",
           "This app allows interactive selection of (a) image features for scatterplotting,",
           "(b) image sets for stratified survival distribution estimation,",
           "and (c) gene sets for expression distribution comparison between strata.",
           "More work is needed to define an interface that distinguishes origins of expression assays.",
           "Data incompleteness is substantial and no effort is made to support",
           "statistical hypothesis testing with this app.",
           "The following upset diagram (see http://caleydo.org/tools/upset/) illustrates",
           "data availability configurations for the image-derived tumor features.") )
      output$upset = renderPlot({
         md = metadata(ivySE)$subBlock
         mm = data.frame(1-is.na(md[,16:26]))
         counts = colSums(mm)
         labels = gsub("normalized_area_", "", names(counts))
         par(mar=c(7,4,2,2))
         barplot(counts, names.arg=labels, las=2,
                 ylab="# subblocks with data",
                 main="Data availability by image feature")
         })
     }
    shinyApp(ui=ui, server=server)
}

---
title: "ivygapSE -- Bioconductor container for Ivy-GAP expression and metadata"
author: "Vincent J. Carey, stvjc at channing.harvard.edu"
date: "`r format(Sys.time(), '%B %d, %Y')`"
vignette: >
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteIndexEntry{ivygapSE -- SummarizedExperiment for Ivy-GAP}
  %\VignetteEncoding{UTF-8}
output:
  BiocStyle::html_document:
    highlight: pygments
    number_sections: yes
    theme: united
    toc: yes
---

# Introduction

CSV files from the Ivy-GAP project have been assembled into a SummarizedExperiment instance.
```{r loadup, echo=FALSE,message=FALSE}
suppressPackageStartupMessages({
library(SummarizedExperiment)
library(ivygapSE)
library(DT)
library(grid)
library(png)
library(ggplot2)
library(limma)
library(randomForest)
})
```
```{r chk,message=FALSE}
library(ivygapSE)
data(ivySE)
ivySE
```
There are several types of metadata collected with the object, including the
README.txt (use `cat(metadata(ivySE)$README, sep="\n")` to see this in R),
the URL where data were retrieved, 
a character vector (builder) with the R code for creating (much of) the SummarizedExperiment, 
and two tables of tumor-specific and
block-specific information.

# Background on the ivyGlimpse app

The ivyGlimpse app is a rapid prototype of a browser-based
interface to salient features of the data.  The
most current code is maintained in the Bioconductor
ivygapSE package, but a public version of the app
may be visited at [shinyapps.io](https://vjcitn.shinyapps.io/ivyglimpse/).

The ivygapSE
package will evolve, based in part on associations
observed through the use of this app.  Briefly, the main
visualization of the app is a scatterplot of user-selected
tumor image features.  All contributions, based
on tumor sub-blocks (that have varying multiplicities per
tumor block and donor) are assembled
together without regard for source; interactive aspects of
the display allow the user to see which donor contributes
each point.  

Strata can be formed interactively by brushing
over the scatterplot; after the brushing event, the survival
times of donors contributing selected points are compared
to donors all of whose contributions lie outside the selection.
Expression data are also stratified in this way and gene-specific
boxplot sets (for user-specified gene sets) are produced for each stratum.

# Summary information on the underlying data

The number of RNA-seq samples is `r ncol(ivySE)`.  The FPKM matrix has dimensions
```{r lkd}
dim(ivySE)
```

There are 42 different tumor donors.
```{r lkse}
length(unique(metadata(ivySE)$tumorDetails$donor_id))
```
However, only 37 donors contributed tumor RNA that was sequenced:
```{r lkcon}
sum(metadata(ivySE)$tumorDetails$tumor_name %in% ivySE$tumor_name)
```
```{r getsbd,echo=FALSE}
subd = metadata(ivySE)$subBlockDetails
dsub = dim(subd)
```

Features of images from sub-blocks were quantified according to the following terminology for
anatomical characteristics.  Not all images provided information
on all attributes.

```{r lkonto,image=TRUE,echo=FALSE}
nomenclat()
```

# Additional details

We have used information in the
[IvyGAP technical white paper](http://help.brain-map.org/display/glioblastoma/Documentation?preview=/8028197/8454231/IvyOverview.pdf) to
spell out additional background on the data underlying the app and
SummarizedExperiment.

## Basic experimental design layout

There are six substudies contributing data in a partly
sequential design.

```{r lkk,echo=FALSE,fig=TRUE}
designOverview()
```

## Tumor-level details

The following table has one record per tumor (N=`r nrow(tumorDetails(ivySE))`).

```{r lkdttum,echo=FALSE}
datatable(tumorDetails(ivySE), options=list(lengthMenu=c(3,5,10,50,100)))
```

## Sub-block-level details

The following table has one record per sub-block (N=`r nrow(subBlockDetails(ivySE))`).
```{r lkdts,echo=FALSE}
datatable(subBlockDetails(ivySE), options=list(lengthMenu=c(3,5,10,50,    100)))
```

## Details on RNA-seq samples

The complete annotation on RNA-seq samples is provided in `colData(ivySE)`.  The
table follows here:

```{r lkcdd,echo=FALSE}
datatable(as.data.frame(colData(ivySE)), options=list(lengthMenu=c(3,5,10,50,100)))
```

### Key RNA-seq subsets

#### Subsets of design origin

The sub-blocks arose from a number of measurement objectives.

```{r lksbbbb}
sb = subBlockDetails(ivySE)
table(sb$study_name)
```

#### Subsets based on structure

We use the `structure_acronym` variable to assess the composition of
sources in the RNA-seq collection.

```{r lksa,fig=TRUE}
struc = as.character(colData(ivySE)$structure_acronym)
spls = strsplit(struc, "-")
basis = vapply(spls, function(x) x[1], character(1))
spec = vapply(spls, function(x) x[2], character(1))
table(basis, exclude=NULL)
barplot(table(basis))
```

Each of the major structural types contributes multiple samples from
specific objectives.  

```{r lktab}
lapply(split(spec,basis), function(x)sort(table(x),decreasing=TRUE))
```

### A simple differential expression study

We have used `r Biocpkg("limma")` to test for differential
expression among samples identified as `reference histology` in
classes `CT`, `CT-mvp`, `CT-pan`, `IT`, and `LE`.  The
resulting mean expression estimates (FPKM scale) 
and moderated test statistics are obtained
as follows:
```{r lklim, cache=TRUE}
library(limma)
ebout = getRefLimma()
```
The ten genes that are most significantly differentially
expressed between conditions CT and CT-mvp are found as follows:
```{r lknnn}
odig = options()$digits
options(digits=3)
limma::topTable(ebout, 2)
options(digits=odig) # revert
```

### Differential expression by molecular subtype

We can bind the molecular subtype information from the tumor
details to the expression sample annotation as follows:
```{r bindmol}
moltype = tumorDetails(ivySE)$molecular_subtype
names(moltype) = tumorDetails(ivySE)$tumor_name
moltype[nchar(moltype)==0] = "missing"
ivySE$moltype = factor(moltype[ivySE$tumor_name])
```

We will confine attention to samples annotated as "reference histology"
and compute the duplicate correlation for modeling the
effect of molecular subtype in the available samples.

```{r setdup, cache=TRUE}
library(limma)
refex = ivySE[, grep("reference", ivySE$structure_acronym)]
refmat = assay(refex)
tydes = model.matrix(~moltype, data=as.data.frame(colData(refex)))
ok = which(apply(tydes,2,sum)>0)  # some subtypes don't have ref histo samples
tydes = tydes[,ok]
block = factor(refex$tumor_id)
dd = duplicateCorrelation(refmat, tydes, block=block)
f2 = lmFit(refmat, tydes, correlation=dd$consensus)
ef2 = eBayes(f2)
colnames(tydes)
topTable(ef2,2)
```

### Classification of structural character

We assess the capacity of the expression measures to
discriminate the structural type (CT, CT-mvp, CT-pan, LE, IT)
using the random forests algorithm.  Features used have
interquartile range (IQR) over all relevant samples exceeding the
median IQR over all genes.

```{r lkrf,fig=TRUE}
refex = ivySE[, grep("reference", ivySE$structure_acronym)]
refex$struc = factor(refex$structure_acronym)
iqrs = rowIQRs(assay(refex))
inds = which(iqrs>quantile(iqrs,.5))
set.seed(1234)
rf1 = randomForest(x=t(assay(refex[inds,])), 
        y=refex$struc, mtry=30, importance=TRUE) 
rf1
varImpPlot(rf1)
```

# Next steps

This vignette was authored in 2018.  The Allen Brain Atlas
resources have matured substantially since then.  This vignette
should be updated for Bioc 3.24.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/imgs.R
\name{designOverview}
\alias{designOverview}
\alias{nomenclat}
\title{render design overview}
\usage{
designOverview()

nomenclat()
}
\value{
a rastergrob grob
}
\description{
render design overview

render anatomic nomenclature
}
\examples{
designOverview()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{ivySE}
\alias{ivySE}
\title{ivySE: SummarizedExperiment for IvyGAP expression data and metadata}
\format{
SummarizedExperiment instance
}
\source{
processed from \url{glioblastoma.alleninstitute.org}; see Note.
}
\usage{
data(ivySE)
}
\description{
ivySE: SummarizedExperiment for IvyGAP expression data and metadata
}
\details{
%vjcair> unzip -l gene*zip \cr
Archive:  gene_expression_matrix_2014-11-25.zip \cr
  Length      Date    Time    Name \cr
---------  ---------- -----   ---- \cr
    50585  03-31-2015 13:27   columns-samples.csv \cr
 86153820  10-31-2014 14:04   fpkm_table.csv \cr
     2015  11-24-2014 18:06   README.txt \cr
  1689619  10-31-2014 13:55   rows-genes.csv \cr
---------                     ------- \cr
 87896039                     4 files \cr
}
\note{
Expression data retrieved from \url{http://glioblastoma.alleninstitute.org/api/v2/well_known_file_download/305873915}
}
\examples{
\dontrun{   # how it was made
ivyFpkm = read.csv("fpkm_table.csv", stringsAsFactors=FALSE, 
      check.names=FALSE)
g = read.csv("rows-genes.csv", stringsAsFactors=FALSE)
library(SummarizedExperiment)
imat = data.matrix(ivyFpkm[,-1])
ivySE = SummarizedExperiment(SimpleList(fpkm=imat))
rowData(ivySE) = g
rownames(ivySE) = g$gene_symbol
col = read.csv("columns-samples.csv", stringsAsFactors=FALSE)
rownames(col) = col$rna_well_id
stopifnot(all.equal(as.character(col$rna_well_id), 
     as.character(colnames(imat))))
colData(ivySE) = DataFrame(col)
colnames(ivySE) = colnames(imat)
metadata(ivySE) = list(README=readLines("README.txt"))
metadata(ivySE)$URL = "http://glioblastoma.alleninstitute.org/static/download.html"
# metadata(ivySE)$builder = readLines("build.R")
de = read.csv("tumor_details.csv", stringsAsFactors=FALSE)
metadata(ivySE)$tumorDetails = de
subbl = read.csv("sub_block_details.csv", stringsAsFactors=FALSE)
metadata(ivySE)$subBlockDetails = subbl
bamtab = read.csv("bam.csv", stringsAsFactors=FALSE)
rownames(bamtab) = as.character(bamtab$rna_well)
bamtab[colnames(ivySE),] -> bamtreo
all.equal(rownames(bamtreo), colnames(ivySE))
colData(ivySE) = cbind(colData(ivySE), bamtreo)
}
data(ivySE)
names(metadata(ivySE))
}
\keyword{datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/expr.R
\name{exprByType}
\alias{exprByType}
\title{simple plot of expression values by structure/expression-based selection in IvyGAP}
\usage{
exprByType(sym, ...)
}
\arguments{
\item{sym}{a gene symbol found among `rownames(ivySE)`}

\item{\dots}{passed to plot, exclusive of ylab, xlab, axes}
}
\value{
invisibly returns a list with two elements: exprs, the vector of expression values, and types, the vector of structure types
}
\description{
simple plot of expression values by structure/expression-based selection in IvyGAP
}
\examples{
exprByType("MYC")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\name{getRefLimma}
\alias{getRefLimma}
\title{provide access to a limma analysis of RNA-seq profiles for reference histology samples}
\usage{
getRefLimma()
}
\value{
an instance of \code{\link[limma]{MArrayLM-class}} representing regularized gene-wise ANOVAs
}
\description{
provide access to a limma analysis of RNA-seq profiles for reference histology samples
}
\note{
Uses \code{\link[utils]{download.file}} to acquire RDS of the output
of \code{\link[limma]{eBayes}} from a public S3 bucket.  The limma model
was fit using \code{\link[limma]{duplicateCorrelation}} to address multiplicity
of contributions per donor.  Comparisons are to samples labeled \code{CT-reference} (cellular tumor, reference contributions),
with coefficients 2-5 corresponding to CT-mvp (microvascular proliferation),
CT-pan (pseudopalisading cells around necrosis), IT (infiltrating tumor),
and LE (leading edge), respectively.
}
\examples{
requireNamespace("limma")
ebout = getRefLimma() # is result of eBayes
colnames(ebout$coef)
limma::topTable(ebout,2)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ivyGlimpse.R
\name{ivyGlimpse}
\alias{ivyGlimpse}
\title{simple app to explore image property quantifications in relation to survival and expression}
\usage{
ivyGlimpse()
}
\value{
Side effect of starting the app only.
}
\description{
simple app to explore image property quantifications in relation to survival and expression
}
\examples{
if (interactive()) print(ivyGlimpse())
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\name{tumorDetails}
\alias{tumorDetails}
\alias{subBlockDetails}
\alias{vocab}
\title{helper functions for data access}
\usage{
tumorDetails(se)

subBlockDetails(se)

vocab()
}
\arguments{
\item{se}{SummarizedExperiment instance, intended to work for ivySE in this package}
}
\value{
data.frames for tumorDetails, subBlockDetails and vocab
}
\description{
helper functions for data access
}
\examples{
data(ivySE)
dim(tumorDetails(ivySE))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/genesets.R
\name{makeGeneSets}
\alias{makeGeneSets}
\title{demonstration of gene set construction for ivyGlimpse app}
\usage{
makeGeneSets()
}
\value{
list of gene sets with attributes facilitating
dropdown construction -- attr(,"fullTitle") is a list of strings
associated with gene set elements (named list with vectors 
of gene symbols constituting sets of interest) \cr
List of 4 \cr
 $ General: Ras-Raf-MEK-Erk/JNK signaling (26 genes) \cr                                      : chr [1:26] "KRAS" "HRAS" "BRAF" "RAF1" ... \cr
 $ Glioblastoma: RTK/Ras/PI3K/AKT Signaling (17 genes) \cr                                    : chr [1:17] "EGFR" "ERBB2" "PDGFRA" "MET" ... \cr
 $ General: PI3K-AKT-mTOR signaling (17 genes)            \cr                                : chr [1:17] "PIK3CA" "PIK3R1" "PIK3R2" "PTEN" ... \cr
 $ Ovarian Cancer: Putative tumor-suppressor genes in epithelial ovarian cancer (16 genes) \cr : chr [1:16] "DIRAS3" "RASSF1" "DLEC1" "SPARC" ... \cr
 - attr(*, "fullTitle")=List of 4 \cr
  ..$ glioRTK  : chr "Glioblastoma: RTK/Ras/PI3K/AKT Signaling (17 genes)" \cr
  ..$ pi3k     : chr "General: PI3K-AKT-mTOR signaling (17 genes)" \cr
  ..$ ovtumsupp: chr "Ovarian Cancer: Putative tumor-suppressor genes in epithelial ovarian cancer (16 genes)" \cr
  ..$ rasraf   : chr "General: Ras-Raf-MEK-Erk/JNK signaling (26 genes)" \cr
}
\description{
demonstration of gene set construction for ivyGlimpse app
}
\note{
Should be replaced by selections from a general catalog.
}
\examples{
str(makeGeneSets())
}
